NaMaster: nmt_workspace_flat Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_workspace_flat Struct Reference

Flat-sky mode-coupling matrix. More...

`#include <namaster.h>`

## Data Fields
int | ncls
| Number of power spectra (1, 2 or 4 depending of the spins of the fields being correlated. More...
flouble | ellcut_x [2]
| Range of ells in the x direction to be masked in Fourie space. More...
flouble | ellcut_y [2]
| Range of ells in the y direction to be masked in Fourie space. More...
int | pe1
| Is the E-mode component of the first field purified? More...
int | pe2
| Is the E-mode component of the second field purified? More...
int | pb1
| Is the B-mode component of the first field purified? More...
int | pb2
| Is the B-mode component of the second field purified? More...
nmt_flatsky_info * | fs
| Contains information about rectangular flat-sky patch. More...
int | is_teb
| Does it hold all MCM elements to compute all of spin0-spin0, 0-2 and 2-2 correlations? More...
int * | n_cells
| Number of unmasked Fourier-space grid points contributing to a given bandpower. More...
flouble ** | coupling_matrix_unbinned
| Unbinned MCM. More...
flouble ** | coupling_matrix_binned
| Binned MCM. More...
nmt_binning_scheme_flat * | bin
| Bandpowers defining the binning. More...
flouble | lmax
| Maximum k-mode used. More...
gsl_matrix * | coupling_matrix_binned_gsl
| GSL version of MCM (prepared for inversion) More...
gsl_permutation * | coupling_matrix_perm
| Complements `coupling_matrix_binned_gsl` for inversion. More...

## Detailed Description

Flat-sky mode-coupling matrix.

Structure containing information about the mode-coupling matrix (MCM) for flat-sky pseudo-CLs.

## Field Documentation

nmt_binning_scheme_flat* nmt_workspace_flat::bin

Bandpowers defining the binning.

flouble** nmt_workspace_flat::coupling_matrix_binned

Binned MCM.

gsl_matrix* nmt_workspace_flat::coupling_matrix_binned_gsl

GSL version of MCM (prepared for inversion)

gsl_permutation* nmt_workspace_flat::coupling_matrix_perm

Complements `coupling_matrix_binned_gsl` for inversion.

flouble** nmt_workspace_flat::coupling_matrix_unbinned

Unbinned MCM.

flouble nmt_workspace_flat::ellcut_x[2]

Range of ells in the x direction to be masked in Fourie space.

flouble nmt_workspace_flat::ellcut_y[2]

Range of ells in the y direction to be masked in Fourie space.

nmt_flatsky_info* nmt_workspace_flat::fs

Contains information about rectangular flat-sky patch.

int nmt_workspace_flat::is_teb

Does it hold all MCM elements to compute all of spin0-spin0, 0-2 and 2-2 correlations?

flouble nmt_workspace_flat::lmax

Maximum k-mode used.

int* nmt_workspace_flat::n_cells

Number of unmasked Fourier-space grid points contributing to a given bandpower.

int nmt_workspace_flat::ncls

Number of power spectra (1, 2 or 4 depending of the spins of the fields being correlated.

int nmt_workspace_flat::pb1

Is the B-mode component of the first field purified?

int nmt_workspace_flat::pb2

Is the B-mode component of the second field purified?

int nmt_workspace_flat::pe1

Is the E-mode component of the first field purified?

int nmt_workspace_flat::pe2

Is the E-mode component of the second field purified?

The documentation for this struct was generated from the following file:

- namaster.h